@@ -32,10 +32,10 @@ public:
     static Device* self();
     static void destroy();
 
-    bool isReady();
-    bool isLaptop();
-    bool isLidClosed();
-    bool isDocked();
+    bool isReady() const;
+    bool isLaptop() const;
+    bool isLidClosed() const;
+    bool isDocked() const;
 
 private Q_SLOTS:
     void changed();
@@ -49,7 +49,7 @@ Q_SIGNALS:
     void aboutToSuspend();
 
 private:
-    explicit Device(QObject* parent = 0);
+    explicit Device(QObject* parent = nullptr);
     virtual ~Device();
 
     void setReady();
